##############################################################################
# The following are touched during the release process by bumpversion.
# Do not modify these directly.
from vtx_common.version import version as _version
from vtx_common.version import verstring as _verstring
